@@ -9,6 +9,7 @@
 # Code Release		: 0.1		17-07-2025	- Initial Alpha Release
 # Code Release		: 0.2		20-07-2025	- Added Pause field
 # Code Release		: 0.3		24-07-2025	- Added Duration field
+# Code Release		: 0.4		01-08-2025	- Added Style field
 # -----------------------------------------------------------------------
 
  if( !defined('CMS_VERSION') ) exit;
@@ -29,6 +30,7 @@ if( isset($params['hid']) && $params['hid'] > 0) {
     $popup->description = $params['description'];
     $popup->pause = $params['pause'];
     $popup->duration = $params['duration'];
+    $popup->style = $params['style'];
     $popup->save();
     $this->SetMessage($this->Lang('popup_saved'));
     $this->RedirectToAdminTab();
