@@ -37,6 +37,8 @@ switch ($oldversion)
 		$dict->ExecuteSQLArray($sqlarray);
 		
 	case "0.2":
-
+	case "0.3":
+	case "0.3.1":
+	
 }
 ?>
\ No newline at end of file
